@@ -1,13 +1,14 @@
 ## File Name: cdm_calc_increment_regularization.R
-## File Version: 0.28
+## File Version: 0.363
 
 cdm_calc_increment_regularization <- function( d1, d2, x0, regular_lam_used,
         max.increment, regular_type, regular_n=1, eps=1E-10, adj_fac=.98)
 {
     d2a <- ( abs(d2) + eps )
     val <- x0 + d1 / d2a
-    vt <- d2a / regular_n
+    vt <- d2a
     val1 <- vt*val
+    regular_lam_used <- regular_n * regular_lam_used
     updated <- cdm_parameter_regularization(x=val1, regular_type=regular_type,
                         regular_lam=regular_lam_used)
     updated <- updated / vt
