@@ -1,5 +1,5 @@
 ## File Name: reglca_calc_ic.R
-## File Version: 0.04
+## File Version: 0.07
 
 reglca_calc_ic <- function( loglike, nclasses, I, N, n_reg, G)
 {
@@ -10,8 +10,10 @@ reglca_calc_ic <- function( loglike, nclasses, I, N, n_reg, G)
     bic <- -2*loglike + Npars*log(N)
     caic <- -2*loglike + ( log(N) + 1 ) * Npars
     deviance <- -2*loglike
+    #* create object ic
+    ic <- list(deviance=deviance, AIC=aic, BIC=bic, CAIC=caic)
     #---- OUTPUT
     res <- list(Npars=Npars, AIC=aic, BIC=bic, CAIC=caic, Nskillpar=Nskillpar, Nipar=Nipar,
-                    deviance=deviance, n_reg=n_reg )
+                    deviance=deviance, n_reg=n_reg, ic=ic )
     return(res)
 }
