@@ -1,5 +1,5 @@
 ## File Name: summary.gdm.R
-## File Version: 1.35
+## File Version: 1.37
 #*******************************************************
 # Summary for gdm object
 summary.gdm <- function( object, file=NULL, ... )
@@ -15,6 +15,9 @@ summary.gdm <- function( object, file=NULL, ... )
     cat("General Diagnostic Model \n\n")
     modeltype <- object$irtmodel
 
+    #-- summary call
+    cdm_print_summary_call(object=object)
+
     cat( "   ", object$N, "Cases, ", object$I, "Items, ", object$G, "Group(s)", ",",
                 object$D, "Dimension(s)\n")
 
